searchData={"content_type":"text/markdown","items":[{"doc":"Defines a GraphQL directive to add constraints to field definitions and argument definitions.\n\nExample\n\n```elixir\ninput_object :my_input do\n  field(:my_field, :integer, directives: [constraints: [min: 1]])\nend\n\n#...\nobject :my_query do\n  field :my_field, non_null(:string) do\n    arg(:my_arg, non_null(:string), directives: [constraints: [format: \"uuid\"]])\n    resolve(&MyResolver.resolve/2)\n  end\nend\n```","ref":"AbsintheConstraints.Directive.html","title":"AbsintheConstraints.Directive","type":"module"},{"doc":"","ref":"AbsintheConstraints.Directive.html#expand_constraints/2","title":"AbsintheConstraints.Directive.expand_constraints/2","type":"function"},{"doc":"Add a deprecation (with an optional reason) to a node.","ref":"AbsintheConstraints.Directive.html#expand_deprecate/2","title":"AbsintheConstraints.Directive.expand_deprecate/2","type":"function"},{"doc":"","ref":"AbsintheConstraints.Directive.html#pipeline/1","title":"AbsintheConstraints.Directive.pipeline/1","type":"function"},{"doc":"Defines an Absinthe Document Phase that validates inputs against constraints defined by the `constraints` directive.\n\nUse add_to_pipeline/2 to add this phase to your Absinthe pipeline.","ref":"AbsintheConstraints.Phase.html","title":"AbsintheConstraints.Phase","type":"module"},{"doc":"","ref":"AbsintheConstraints.Phase.html#add_to_pipeline/2","title":"AbsintheConstraints.Phase.add_to_pipeline/2","type":"function"},{"doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/1","title":"AbsintheConstraints.Phase.flag_invalid/1","type":"function"},{"doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/2","title":"AbsintheConstraints.Phase.flag_invalid/2","type":"function"},{"doc":"","ref":"AbsintheConstraints.Phase.html#flag_invalid/3","title":"AbsintheConstraints.Phase.flag_invalid/3","type":"function"},{"doc":"","ref":"AbsintheConstraints.Phase.html#inherit_invalid/3","title":"AbsintheConstraints.Phase.inherit_invalid/3","type":"function"},{"doc":"","ref":"AbsintheConstraints.Phase.html#put_flag/2","title":"AbsintheConstraints.Phase.put_flag/2","type":"function"},{"doc":"Defines all the constraint handlers for the `constraints` directive.","ref":"AbsintheConstraints.Validator.html","title":"AbsintheConstraints.Validator","type":"module"},{"doc":"","ref":"AbsintheConstraints.Validator.html#handle_constraint/2","title":"AbsintheConstraints.Validator.handle_constraint/2","type":"function"},{"doc":"# Absinthe Constraints\n\nAn absinthe library to add type constraints to your GraphQL schema using directives.","ref":"readme.html","title":"Absinthe Constraints","type":"extras"},{"doc":"Install from [Hex.pm](https://hex.pm/packages/absinthe_constraints)\n\n```elixir\ndef deps do\n  [\n    {:absinthe_constraints, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Absinthe Constraints","type":"extras"},{"doc":"##","ref":"readme.html#usage","title":"Usage - Absinthe Constraints","type":"extras"},{"doc":"```elixir\ndefmodule MyAppWeb.Schema do\n  use Absinthe.Schema\n\n  @prototype_schema AbsintheConstraints.Directive\n\n  # Use `import_sdl`, etc...\nend\n```\n\n##","ref":"readme.html#1-add-the-constraints-directive-s-prototype-schema-to-your-schema","title":"1. Add the `constraints` directive's prototype schema to your schema - Absinthe Constraints","type":"extras"},{"doc":"Example using `Absinthe.Plug`:\n\n```elixir\n# Somewhere in your router\n\ndef my_pipeline(config, opts) do\n  config\n  |> Absinthe.Plug.default_pipeline(opts)\n  |> AbsintheConstraints.Phase.add_to_pipeline(opts)\nend\n\nforward(\"/\", Absinthe.Plug, schema: MyAppWeb.Schema, pipeline: {__MODULE__, :my_pipeline})\n```\n\n##","ref":"readme.html#2-add-the-document-phase-to-your-absinthe-pipeline","title":"2. Add the document phase to your absinthe Pipeline - Absinthe Constraints","type":"extras"},{"doc":"```elixir\n# Somewhere in your schema\n\n# Adding constraints to input object's fields\ninput_object :coordinates do\n  field(:latitude, non_null(:float), directives: [constraints: [min: -90, max: 90]])\n  field(:longitude, non_null(:float), directives: [constraints: [min: -180, max: 180]])\nend\n\n# Adding constraints to query field's arguments\nobject :my_queries do\n  field :my_field, non_null(:string) do\n    arg(:id, non_null(:string), directives: [constraints: [format: \"uuid\"]])\n    arg()\n    resolve(&my_resolver/2)\n  end\nend\n```","ref":"readme.html#3-add-constraints-to-your-schema","title":"3. Add constraints to your schema - Absinthe Constraints","type":"extras"}]}